betty.test_utils.license module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.test_utils.license module

Test utilities for `betty.license`.

class betty.test_utils.license.DummyLicense

  Bases: `DummyPlugin`, `License`

  A dummy license implementation.

  property summary: Localizable

    The license summary.

  property text: Localizable

    The full license text.

class betty.test_utils.license.LicenseTestBase

  Bases: `PluginInstanceTestBase`[`License`]

  A base class for testing `betty.license.License` implementations.

  test_summary() → None

    Tests `betty.license.License.summary()` implementations.

  test_text() → None

    Tests `betty.license.License.text()` implementations.

  test_url() → None

    Tests `betty.license.License.url()` implementations.